function [u, v, X, T, M, N] = ...
    ShallowWaterSystem(g, u0, uL, uR, v0, vL, vR, t, x, lambda, h)
% Ukad rwna 
%     u_t + (u*v)_x = 0                                     (1)
%     (u*v)_t + (u*v^2 + g/2 * u^2)_x = 0,                  (2)
% gdzie g jest przyspieszeniem ziemskim, z warunkiem pocztkowym 
%     u(t0,x) = u0(x)
%     v(t0,x) = v0(x)
% i warunkami pocztkowymi typu Dirichleta:
%     u(t,x0) = uL(t)
%     u(t,x1) = uR(t)
%     v(t,x0) = vL(t)
%     v(t,x1) = vR(t)
% Parametry: 
% t = [t0, t1] - przedzia czasowy
% x = [x0, x1] - przedzia przestrzenny
% h - krok przestrzenny, lambda = k/h, gdzie k - krok czasowy.

% krok czasowy
k = lambda*h;

% punkty siatki
X = x(1):h:x(2);   M = length(X);
T = t(1):k:t(2);   N = length(T);

% zainicjowanie macierzy rozwizania:
u = zeros(M,N);
v = zeros(M,N);

% uzupenienie warunku pocztkowego dla n = 1
u(:,1) = u0(X);
v(:,1) = v0(X);

% uzupenienie warunku brzegowego
u(1,:) = uL(T);     u(M,:) = uR(T);
v(1,:) = vL(T);     v(M,:) = vR(T);

% w kadym kroku ptli gwnej, wartoci funkcji h oraz u s obliczane
% jako rozwizania ukadu rwna A*r=b, gdzie r jest wektorem o dugoci
% 2*M - pierwsze M wsprzdnych odpowiada funkcji u, kolejne M
% wsprzdnych to funkcja v.
% Naley o tym pamita przy uzupenianiu elementw macierzy A.

% zainicjowanie macierzy ukadu rwna
A = zeros(2*M,2*M);
b = zeros(2*M,1);

% ptla gwna
for n = 2:N
    for m = 2:(M-1)
        % DO UZUPENIENIA
        % pierwsze rwnanie (1)
        
        % prawa strona
        
        
        % drugie rwnanie (2)
        
        % prawa strona
        
    end
    
    % DO UZUPENIENIA
    % warunki brzegowe
    
    
    % rozwizanie ukadu rwna i uzupenienie rozwizania
    r = A\b;
    u(:,n) = r(1:M,1);
    v(:,n) = r(M+1:M+M,1);
end